from phlite_grpph import grpph, grpph_with_involution
from pprint import pprint
import time


def do_complete(N):
    essential, pairings = grpph(
        N, [(i, j, 1.0) for i in range(N) for j in range(N) if i != j]
    )

    assert len(essential[0]) == 1
    assert len(essential[1]) == 0
    assert len(pairings[0]) == 0
    assert len(pairings[1]) == N * (N - 1) - N + 1

    print("Done complete")


def do_cycle(N, with_reps=False):
    if with_reps:
        essential, pairings, reps = grpph_with_involution(
            N, [(i, (i + 1) % N, 1.0) for i in range(N)]
        )
        assert len(reps) == 1
        assert len(reps[0]) == N
    else:
        essential, pairings = grpph(N, [(i, (i + 1) % N, 1.0) for i in range(N)])

    assert len(essential[0]) == 1
    assert len(essential[1]) == 0
    assert len(pairings[0]) == 0
    assert len(pairings[1]) == 1

    if with_reps:
        return essential, pairings, reps
    else:
        return essential, pairings


N = 200

tic0 = time.time()
do_cycle(N, with_reps=False)
tic1 = time.time()
print(f"Without reps: {tic1 - tic0}")

tic2 = time.time()
do_cycle(N, with_reps=True)
tic3 = time.time()
print(f"With reps   : {tic3 - tic2}")



from phlite_grpph import grpph_with_involution
import logging
from pprint import pprint

FORMAT = '%(levelname)s %(name)s %(asctime)-15s %(filename)s:%(lineno)d %(message)s'
logging.basicConfig(format=FORMAT)
logging.getLogger().setLevel(logging.INFO)

essential, pairings, reps = grpph_with_involution(
    6,
    [
        (0, 1, 10.0),
        (0, 2, 10.0),
        (1, 3, 10.0),
        (2, 3, 10.0),
        (0, 3, 20.0),
        (0, 4, 5.0),
        (4, 5, 10.0),
        (5, 3, 5.0),
    ],
)

print(essential)
print(pairings)
pprint(reps)
